///File : LoadScreen.cpp
//------------------------------------------------------------------------------
/*
    This file is part of MaxiShoot.

    MaxiShoot is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    MaxiShoot is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with MaxiShoot.  If not, see <http://www.gnu.org/licenses/>.
*/
//------------------------------------------------------------------------------
#include "LoadScreen.hpp"
//------------------------------------------------------------------------------
LoadScreen::LoadScreen(ConfigObj *configObj) : Screen(configObj)
{

}
//------------------------------------------------------------------------------
int LoadScreen::Run (sf::RenderWindow &App)
{
    // Params
    App.SetView(sf::View(sf::FloatRect(0, 0, SCREEN_WIDTH, SCREEN_HEIGHT)));
    App.ShowMouseCursor(false);

    // VerticalSync
    #if V_SYNC_IN_MENU
    App.UseVerticalSync(true);
    #else
    App.UseVerticalSync(false);
    #endif

    #if not defined NO_LOAD_THREAD
    // Colors && pos
    sf::Vector2f progressBarPos(SCREEN_WIDTH / 2 - PROGRESS_BAR_WIDTH / 2, SCREEN_HEIGHT / 2 - PROGRESS_BAR_HEIGHT / 2);
    sf::Color progressBarColor(0, 255, 0);
    sf::Color progressBarBorderPointsColor(0, 0, 0);
    sf::Color progressBarBorderOutlineColor(0, 0, 255);

    // Shapes
    sf::Shape ProgressBar;
    ProgressBar = sf::Shape::Rectangle(progressBarPos.x, progressBarPos.y, progressBarPos.x + 1, progressBarPos.y + PROGRESS_BAR_HEIGHT, progressBarColor);

    sf::Shape Border;
    Border.AddPoint(-PROGRESS_BAR_BORDER_SPACE, -PROGRESS_BAR_BORDER_SPACE, progressBarBorderPointsColor, progressBarBorderOutlineColor);
    Border.AddPoint(PROGRESS_BAR_WIDTH + PROGRESS_BAR_BORDER_SPACE, -PROGRESS_BAR_BORDER_SPACE, progressBarBorderPointsColor, progressBarBorderOutlineColor);
    Border.AddPoint(PROGRESS_BAR_WIDTH + PROGRESS_BAR_BORDER_SPACE, PROGRESS_BAR_HEIGHT + PROGRESS_BAR_BORDER_SPACE, progressBarBorderPointsColor, progressBarBorderOutlineColor);
    Border.AddPoint(-PROGRESS_BAR_BORDER_SPACE, PROGRESS_BAR_HEIGHT + PROGRESS_BAR_BORDER_SPACE, progressBarBorderPointsColor, progressBarBorderOutlineColor);
    Border.SetOutlineWidth(PROGRESS_BAR_BORDER_SIZE);
    Border.SetPosition(progressBarPos);

    // Load
    m_ConfigObj->LoadMode();
    #else
    sf::String LoadTxt("Chargement en cours...");
    LoadTxt.SetPosition(sf::Vector2f(SCREEN_WIDTH / 2 - LoadTxt.GetRect().GetWidth() / 2, SCREEN_HEIGHT / 2 - LoadTxt.GetRect().GetHeight() / 2));


    #endif

    while (m_RcManager->GetLoadProgress() != 100)
    {
        sf::Event Event;
        while (App.GetEvent(Event))
        {
            // Window closed
            if (Event.Type == sf::Event::Closed)
            {
                return (-1);
            }
            //Key pressed
            if (Event.Type == sf::Event::KeyPressed && Event.Key.Code == sf::Key::Escape)
            {
                return (-1);
            }
        }

        #if not defined NO_LOAD_THREAD
        ProgressBar = sf::Shape::Rectangle(progressBarPos.x, progressBarPos.y, progressBarPos.x + m_RcManager->GetLoadProgress() / 100 * PROGRESS_BAR_WIDTH, progressBarPos.y + PROGRESS_BAR_HEIGHT, progressBarColor);

        //Drawing
        App.Clear();

        App.Draw(Border);
        App.Draw(ProgressBar);

        App.Display();
        #else
        //Drawing
        App.Clear();

        App.Draw(LoadTxt);

        App.Display();

        // On charge quand la fenêtre est dessinée (et pas avant).
        m_ConfigObj->LoadMode();
        #endif
    }

    return (1); // Go to menu !
}

